sccoda.model.dirichlet\_models
==============================

.. automodule:: sccoda.model.dirichlet_models

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      BaselineModel
      CompositionalModel
      NoBaselineModel
      NoBaselineModelNoEdward
   
   

   
   
   